@@ -24,7 +24,6 @@
 # Germany
 #
 # http://www.imbs-luebeck.de
-# wright@imbs.uni-luebeck.de
 # -------------------------------------------------------------------------------
 
 ##' Ranger is a fast implementation of Random Forest (Breiman 2001) or recursive partitioning, particularly suited for high dimensional data.
@@ -98,7 +97,7 @@
 ##' @param keep.inbag Save how often observations are in-bag in each tree. 
 ##' @param holdout Hold-out mode. Hold-out all samples with case weight 0 and use these for variable importance and prediction error.
 ##' @param num.threads Number of threads. Default is number of CPUs available.
-##' @param save.memory Use memory saving (but slower) splitting mode. No effect for GWAS data. Warning: This option slows down the tree growing, use only if you encounter memory problems.
+##' @param save.memory Use memory saving (but slower) splitting mode. No effect for survival and GWAS data. Warning: This option slows down the tree growing, use only if you encounter memory problems.
 ##' @param verbose Show computation status and estimated runtime.
 ##' @param seed Random seed. Default is \code{NULL}, which generates the seed from \code{R}. 
 ##' @param dependent.variable.name Name of dependent variable, needed if no formula given. For survival forests this is the time variable.
@@ -176,6 +175,7 @@
 ##' @importFrom Rcpp evalCpp
 ##' @import stats 
 ##' @import utils
+##' @importFrom Matrix Matrix
 ##' @export
 ranger <- function(formula = NULL, data = NULL, num.trees = 500, mtry = NULL,
                    importance = "none", write.forest = TRUE, probability = FALSE,
@@ -195,7 +195,7 @@ ranger <- function(formula = NULL, data = NULL, num.trees = 500, mtry = NULL,
   ## GenABEL GWA data
   if ("gwaa.data" %in% class(data)) {
     snp.names <- data@gtdata@snpnames
-    sparse.data <- data@gtdata@gtps@.Data
+    snp.data <- data@gtdata@gtps@.Data
     data <- data@phdata
     if ("id" %in% names(data)) {
       data$"id" <- NULL
@@ -203,10 +203,21 @@ ranger <- function(formula = NULL, data = NULL, num.trees = 500, mtry = NULL,
     gwa.mode <- TRUE
     save.memory <- FALSE
   } else {
-    sparse.data <- as.matrix(0)
+    snp.data <- as.matrix(0)
     gwa.mode <- FALSE
   }
   
+  ## Sparse matrix data
+  if (inherits(data, "Matrix")) {
+    if (!("dgCMatrix" %in% class(data))) {
+      stop("Error: Currently only sparse data of class 'dgCMatrix' supported.")
+    }
+  
+    if (!is.null(formula)) {
+      stop("Error: Sparse matrices only supported with alternative interface. Use dependent.variable.name instead of formula.")
+    }
+  }
+    
   ## Formula interface. Use whole data frame is no formula provided and depvarname given
   if (is.null(formula)) {
     if (is.null(dependent.variable.name)) {
@@ -242,7 +253,7 @@ ranger <- function(formula = NULL, data = NULL, num.trees = 500, mtry = NULL,
     } else {
       treetype <- 1
     }
-  } else if (is.numeric(response) & is.vector(response)) {
+  } else if (is.numeric(response) && is.vector(response)) {
     if (!is.null(classification) && classification) {
       treetype <- 1
     } else if (probability) {
@@ -250,7 +261,7 @@ ranger <- function(formula = NULL, data = NULL, num.trees = 500, mtry = NULL,
     } else {
       treetype <- 3
     }
-  } else if (class(response) == "Surv" | is.data.frame(response) | is.matrix(response)) {
+  } else if (class(response) == "Surv" || is.data.frame(response) || is.matrix(response)) {
     treetype <- 5
   } else {
     stop("Error: Unsupported type of dependent variable.")
@@ -288,7 +299,7 @@ ranger <- function(formula = NULL, data = NULL, num.trees = 500, mtry = NULL,
   }
   
   ## Recode characters as factors and recode factors if 'order' mode
-  if (!is.matrix(data.selected)) {
+  if (!is.matrix(data.selected) && !inherits(data.selected, "Matrix")) {
     character.idx <- sapply(data.selected, is.character)
     
     if (respect.unordered.factors == "order") {
@@ -329,12 +340,12 @@ ranger <- function(formula = NULL, data = NULL, num.trees = 500, mtry = NULL,
   }
   
   ## Input data and variable names, create final data matrix
-  if (!is.null(formula) & treetype == 5) {
+  if (!is.null(formula) && treetype == 5) {
     data.final <- data.matrix(cbind(response[, 1], response[, 2],
                               data.selected[-1]))
     colnames(data.final) <- c(dependent.variable.name, status.variable.name,
                               independent.variable.names)
-  } else if (is.matrix(data.selected)) {
+  } else if (is.matrix(data.selected) || inherits(data.selected, "Matrix")) {
     data.final <- data.selected
   } else {
     data.final <- data.matrix(data.selected)
@@ -350,14 +361,14 @@ ranger <- function(formula = NULL, data = NULL, num.trees = 500, mtry = NULL,
   }
   
   ## Number of trees
-  if (!is.numeric(num.trees) | num.trees < 1) {
+  if (!is.numeric(num.trees) || num.trees < 1) {
     stop("Error: Invalid value for num.trees.")
   }
   
   ## mtry
   if (is.null(mtry)) {
     mtry <- 0
-  } else if (!is.numeric(mtry) | mtry < 0) {
+  } else if (!is.numeric(mtry) || mtry < 0) {
     stop("Error: Invalid value for mtry")
   }
   
@@ -375,24 +386,24 @@ ranger <- function(formula = NULL, data = NULL, num.trees = 500, mtry = NULL,
   ## Default 0 -> detect from system in C++.
   if (is.null(num.threads)) {
     num.threads = 0
-  } else if (!is.numeric(num.threads) | num.threads < 0) {
+  } else if (!is.numeric(num.threads) || num.threads < 0) {
     stop("Error: Invalid value for num.threads")
   }
   
   ## Minumum node size
   if (is.null(min.node.size)) {
     min.node.size <- 0
-  } else if (!is.numeric(min.node.size) | min.node.size < 0) {
+  } else if (!is.numeric(min.node.size) || min.node.size < 0) {
     stop("Error: Invalid value for min.node.size")
   }
   
   ## Sample fraction
-  if (!is.numeric(sample.fraction) | sample.fraction <= 0 | sample.fraction > 1) {
+  if (!is.numeric(sample.fraction) || sample.fraction <= 0 || sample.fraction > 1) {
     stop("Error: Invalid value for sample.fraction. Please give a value in (0,1].")
   }
   
   ## Importance mode
-  if (is.null(importance) | importance == "none") {
+  if (is.null(importance) || importance == "none") {
     importance.mode <- 0
   } else if (importance == "impurity") {
     importance.mode <- 1
@@ -456,7 +467,7 @@ ranger <- function(formula = NULL, data = NULL, num.trees = 500, mtry = NULL,
     use.always.split.variables <- TRUE
   }
   
-  if (use.split.select.weights & use.always.split.variables) {
+  if (use.split.select.weights && use.always.split.variables) {
     stop("Error: Please use only one option of split.select.weights and always.split.variables.")
   }
   
@@ -466,6 +477,8 @@ ranger <- function(formula = NULL, data = NULL, num.trees = 500, mtry = NULL,
       splitrule <- "logrank"
     } else if (treetype == 3) {
       splitrule <- "variance"
+    } else if (treetype %in% c(1, 9)) {
+      splitrule <- "gini"
     }
     splitrule.num <- 1
   } else if (splitrule == "logrank") {
@@ -474,26 +487,32 @@ ranger <- function(formula = NULL, data = NULL, num.trees = 500, mtry = NULL,
     } else {
       stop("Error: logrank splitrule applicable to survival data only.")
     }
+  } else if (splitrule == "gini") {
+    if (treetype %in% c(1, 9)) {
+      splitrule.num <- 1
+    } else {
+      stop("Error: Gini splitrule applicable to classification data only.")
+    }
   } else if (splitrule == "variance") {
     if (treetype == 3) {
-      splitrule.num <- 2
+      splitrule.num <- 1
     } else {
       stop("Error: variance splitrule applicable to regression data only.")
     }
-  } else if (splitrule == "auc" | splitrule == "C") {
+  } else if (splitrule == "auc" || splitrule == "C") {
     if (treetype == 5) {
       splitrule.num <- 2
     } else {
       stop("Error: C index splitrule applicable to survival data only.")
     }
-  } else if (splitrule == "auc_ignore_ties" | splitrule == "C_ignore_ties") {
+  } else if (splitrule == "auc_ignore_ties" || splitrule == "C_ignore_ties") {
     if (treetype == 5) {
       splitrule.num <- 3
     } else {
       stop("Error: C index splitrule applicable to survival data only.")
     }
   } else if (splitrule == "maxstat") {
-    if (treetype == 5 | treetype == 3) {
+    if (treetype == 5 || treetype == 3) {
       splitrule.num <- 4
     } else {
       stop("Error: maxstat splitrule applicable to regression or survival data only.")
@@ -505,18 +524,18 @@ ranger <- function(formula = NULL, data = NULL, num.trees = 500, mtry = NULL,
   }
   
   ## Maxstat splitting
-  if (alpha < 0 | alpha > 1) {
+  if (alpha < 0 || alpha > 1) {
     stop("Error: Invalid value for alpha, please give a value between 0 and 1.")
   }
-  if (minprop < 0 | minprop > 0.5) {
+  if (minprop < 0 || minprop > 0.5) {
     stop("Error: Invalid value for minprop, please give a value between 0 and 0.5.")
   }
 
   ## Extra trees
-  if (!is.numeric(num.random.splits) | num.random.splits < 1) {
+  if (!is.numeric(num.random.splits) || num.random.splits < 1) {
     stop("Error: Invalid value for num.random.splits, please give a positive integer.")
   }
-  if (splitrule.num == 5 & save.memory & respect.unordered.factors == "partition") {
+  if (splitrule.num == 5 && save.memory && respect.unordered.factors == "partition") {
     stop("Error: save.memory option not possible in extraTrees mode with unordered predictors.")
   }
 
@@ -541,7 +560,7 @@ ranger <- function(formula = NULL, data = NULL, num.trees = 500, mtry = NULL,
       unordered.factor.variables <- c("0", "0")
       use.unordered.factor.variables <- FALSE
     } 
-  } else if (respect.unordered.factors == "ignore" | respect.unordered.factors == "order") {
+  } else if (respect.unordered.factors == "ignore" || respect.unordered.factors == "order") {
     ## Ordering for "order" is handled above
     unordered.factor.variables <- c("0", "0")
     use.unordered.factor.variables <- FALSE
@@ -550,7 +569,7 @@ ranger <- function(formula = NULL, data = NULL, num.trees = 500, mtry = NULL,
   }
 
   ## Unordered maxstat splitting not possible
-  if (use.unordered.factor.variables & !is.null(splitrule)) {
+  if (use.unordered.factor.variables && !is.null(splitrule)) {
     if (splitrule == "maxstat") {
       stop("Error: Unordered factor splitting not implemented for 'maxstat' splitting rule.")
     } else if (splitrule %in% c("C", "auc", "C_ignore_ties", "auc_ignore_ties")) {
@@ -562,11 +581,11 @@ ranger <- function(formula = NULL, data = NULL, num.trees = 500, mtry = NULL,
   if (respect.unordered.factors == "order") {
     if (treetype == 5) {
       warning("Warning: The 'order' mode for unordered factor handling for survival outcomes is experimental.")
-    } else if (treetype == 1 | treetype == 9) {
+    } else if (treetype == 1 || treetype == 9) {
       if (nlevels(response) > 2) {
         warning("Warning: The 'order' mode for unordered factor handling for multiclass classification is experimental.")
       }
-    } else if (treetype == 3 & splitrule == "maxstat") {
+    } else if (treetype == 3 && splitrule == "maxstat") {
       warning("Warning: The 'order' mode for unordered factor handling with the 'maxstat' splitrule is experimental.")
     }
   }
@@ -579,19 +598,29 @@ ranger <- function(formula = NULL, data = NULL, num.trees = 500, mtry = NULL,
   ## No loaded forest object
   loaded.forest <- list()
   
+  ## Use sparse matrix
+  if ("dgCMatrix" %in% class(data.final)) {
+    sparse.data <- data.final
+    data.final <- matrix(c(0, 0))
+    use.sparse.data <- TRUE
+  } else {
+    sparse.data <- Matrix(matrix(c(0, 0)))
+    use.sparse.data <- FALSE
+  }
+  
   ## Clean up
   rm("data.selected")
-  
+
   ## Call Ranger
   result <- rangerCpp(treetype, dependent.variable.name, data.final, variable.names, mtry,
                       num.trees, verbose, seed, num.threads, write.forest, importance.mode,
                       min.node.size, split.select.weights, use.split.select.weights,
                       always.split.variables, use.always.split.variables,
-                      status.variable.name, prediction.mode, loaded.forest, sparse.data,
+                      status.variable.name, prediction.mode, loaded.forest, snp.data,
                       replace, probability, unordered.factor.variables, use.unordered.factor.variables, 
                       save.memory, splitrule.num, case.weights, use.case.weights, predict.all, 
                       keep.inbag, sample.fraction, alpha, minprop, holdout, prediction.type, 
-                      num.random.splits)
+                      num.random.splits, sparse.data, use.sparse.data)
   
   if (length(result) == 0) {
     stop("User interrupt or internal error.")
@@ -603,7 +632,7 @@ ranger <- function(formula = NULL, data = NULL, num.trees = 500, mtry = NULL,
   }
 
   ## Set predictions
-  if (treetype == 1 & is.factor(response)) {
+  if (treetype == 1 && is.factor(response)) {
     result$predictions <- integer.to.factor(result$predictions,
                                             levels(response))
     true.values <- integer.to.factor(unlist(data.final[, dependent.variable.name]),
@@ -619,7 +648,7 @@ ranger <- function(formula = NULL, data = NULL, num.trees = 500, mtry = NULL,
     result$chf <- result$predictions
     result$predictions <- NULL
     result$survival <- exp(-result$chf)
-  } else if (treetype == 9 & !is.matrix(data)) {
+  } else if (treetype == 9 && !is.matrix(data)) {
     if (is.list(result$predictions)) {
       result$predictions <- do.call(rbind, result$predictions)
     } 
@@ -633,9 +662,7 @@ ranger <- function(formula = NULL, data = NULL, num.trees = 500, mtry = NULL,
   }
   
   ## Splitrule
-  if (treetype == 3 | treetype == 5) {
-    result$splitrule <- splitrule
-  }
+  result$splitrule <- splitrule
   
   ## Set treetype
   if (treetype == 1) {
@@ -664,7 +691,7 @@ ranger <- function(formula = NULL, data = NULL, num.trees = 500, mtry = NULL,
     class(result$forest) <- "ranger.forest"
     
     ## In 'ordered' mode, save covariate levels
-    if (respect.unordered.factors == "order" & !is.matrix(data)) {
+    if (respect.unordered.factors == "order" && !is.matrix(data)) {
       result$forest$covariate.levels <- covariate.levels
     }
   }
