@@ -21,9 +21,9 @@
  Universität zu Lübeck
  Ratzeburger Allee 160
  23562 Lübeck
+ Germany
 
  http://www.imbs-luebeck.de
- wright@imbs.uni-luebeck.de
  #-------------------------------------------------------------------------------*/
 
 #include <unordered_map>
@@ -80,9 +80,9 @@ double TreeClassification::estimate(size_t nodeID) {
   return (mostFrequentValue(class_count, random_number_generator));
 }
 
-void TreeClassification::appendToFileInternal(std::ofstream& file) {
+void TreeClassification::appendToFileInternal(std::ofstream& file) { // #nocov start
   // Empty on purpose
-}
+} // #nocov end
 
 bool TreeClassification::splitNodeInternal(size_t nodeID, std::vector<size_t>& possible_split_varIDs) {
 
@@ -274,6 +274,11 @@ void TreeClassification::findBestSplitValueSmallQ(size_t nodeID, size_t varID, s
       best_value =  (possible_split_values[i] + possible_split_values[i + 1]) / 2;
       best_varID = varID;
       best_decrease = decrease;
+
+      // Use smaller value if average is numerically the same as the larger value
+      if (best_value == possible_split_values[i + 1]) {
+        best_value = possible_split_values[i];
+      }
     }
   }
 
@@ -345,6 +350,11 @@ void TreeClassification::findBestSplitValueLargeQ(size_t nodeID, size_t varID, s
       best_value = (data->getUniqueDataValue(varID, i) + data->getUniqueDataValue(varID, j)) / 2;
       best_varID = varID;
       best_decrease = decrease;
+
+      // Use smaller value if average is numerically the same as the larger value
+      if (best_value == data->getUniqueDataValue(varID, j)) {
+        best_value = data->getUniqueDataValue(varID, i);
+      }
     }
   }
 
