@@ -21,9 +21,9 @@
  Universität zu Lübeck
  Ratzeburger Allee 160
  23562 Lübeck
+ Germany
 
  http://www.imbs-luebeck.de
- wright@imbs.uni-luebeck.de
  #-------------------------------------------------------------------------------*/
 
 #include "TreeProbability.h"
@@ -79,7 +79,7 @@ void TreeProbability::addToTerminalNodes(size_t nodeID) {
   }
 }
 
-void TreeProbability::appendToFileInternal(std::ofstream& file) {
+void TreeProbability::appendToFileInternal(std::ofstream& file) { // #nocov start
 
   // Add Terminal node class counts
   // Convert to vector without empty elements and save
@@ -93,7 +93,7 @@ void TreeProbability::appendToFileInternal(std::ofstream& file) {
   }
   saveVector1D(terminal_nodes, file);
   saveVector2D(terminal_class_counts_vector, file);
-}
+} // #nocov end
 
 bool TreeProbability::splitNodeInternal(size_t nodeID, std::vector<size_t>& possible_split_varIDs) {
 
@@ -284,6 +284,11 @@ void TreeProbability::findBestSplitValueSmallQ(size_t nodeID, size_t varID, size
       best_value = (possible_split_values[i] + possible_split_values[i + 1]) / 2;
       best_varID = varID;
       best_decrease = decrease;
+
+      // Use smaller value if average is numerically the same as the larger value
+      if (best_value == possible_split_values[i + 1]) {
+        best_value = possible_split_values[i];
+      }
     }
   }
 
@@ -355,6 +360,11 @@ void TreeProbability::findBestSplitValueLargeQ(size_t nodeID, size_t varID, size
       best_value = (data->getUniqueDataValue(varID, i) + data->getUniqueDataValue(varID, j)) / 2;
       best_varID = varID;
       best_decrease = decrease;
+
+      // Use smaller value if average is numerically the same as the larger value
+      if (best_value == data->getUniqueDataValue(varID, j)) {
+        best_value = data->getUniqueDataValue(varID, i);
+      }
     }
   }
 
